==> security-officer-server-3.2-sources.jar: org/odpi/openmetadata/accessservices/securityofficer/server/utils/Constants.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.accessservices.securityofficer.server.utils;

public class Constants {

    public static final String SECURITY_OFFICER = "SecurityOfficerOMAS";
    public static final String SCHEMA_ATTRIBUTE = "SchemaAttribute";
    public static final String SECURITY_TAGS = "SecurityTags";
    public static final String SECURITY_LABELS = "securityLabels";
    public static final String SECURITY_PROPERTIES = "securityProperties";
    public static final String SCHEMA_ELEMENT = "SchemaElement";
    public static final String RELATIONAL_TABLE = "RelationalTable";
    public static final String RELATIONAL_COLUMN = "RelationalColumn";
    public static final String SCHEMA_ATTRIBUTE_TYPE = "SchemaAttributeType";
    public static final String ATTRIBUTE_FOR_SCHEMA = "AttributeForSchema";
    public static final String SEMANTIC_ASSIGNMENT = "SemanticAssignment";
    public static final String SEMANTIC_ASSIGNMENT_GUID = "e6670973-645f-441a-bec7-6f5570345b92";
    public static final String CONFIDENTIALITY = "Confidentiality";
    public static final String GLOSSARY_TERM = "GlossaryTerm";
    public static final String SOURCE = "source";

    public static final String SECURITY_TAG = "SecurityTags";
    public static final String SECURITY_TAGS_GUID =  "a0b07a86-9fd3-40ca-bb9b-fe83c6981deb";

    public static final String NESTED_SCHEMA_ATTRIBUTE = "NestedSchemaAttribute";
    public static final String NESTED_SCHEMA_ATTRIBUTE_GUID = "0ffb9d87-7074-45da-a9b0-ae0859611133";

    public static final String NAME = "name";
    public static final String DESCRIPTION = "description";
    public static final String TYPE = "type";
    public static final String VERSION = "version";
    public static final String PATCH_LEVEL = "patchLevel";
    public static final String DEFAULT_SCHEMA_NAME = "gaian";
    public static final String QUALIFIED_NAME = "qualifiedName";
    public static final String DISPLAY_NAME = "displayName";
    public static final String SOFTWARE_SERVER_CAPABILITY_GUID = "fe30a033-8f86-4d17-8986-e6166fa24177";
    public static final String SOFTWARE_SERVER_CAPABILITY = "SoftwareServerCapability";

    private Constants() {
    }
}

==> security-officer-server-3.12-sources.jar: org/odpi/openmetadata/accessservices/securityofficer/server/utils/Constants.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.accessservices.securityofficer.server.utils;

public class Constants {

    public static final String SECURITY_OFFICER = "SecurityOfficerOMAS";
    public static final String SCHEMA_ATTRIBUTE = "SchemaAttribute";
    public static final String SECURITY_TAGS = "SecurityTags";
    public static final String SECURITY_LABELS = "securityLabels";
    public static final String SECURITY_PROPERTIES = "securityProperties";
    public static final String SCHEMA_ELEMENT = "SchemaElement";
    public static final String RELATIONAL_TABLE = "RelationalTable";
    public static final String RELATIONAL_COLUMN = "RelationalColumn";
    public static final String SCHEMA_ATTRIBUTE_TYPE = "SchemaAttributeType";
    public static final String ATTRIBUTE_FOR_SCHEMA = "AttributeForSchema";
    public static final String SEMANTIC_ASSIGNMENT = "SemanticAssignment";
    public static final String SEMANTIC_ASSIGNMENT_GUID = "e6670973-645f-441a-bec7-6f5570345b92";
    public static final String CONFIDENTIALITY = "Confidentiality";
    public static final String GLOSSARY_TERM = "GlossaryTerm";
    public static final String SOURCE = "source";

    public static final String SECURITY_TAG = "SecurityTags";
    public static final String SECURITY_TAGS_GUID =  "a0b07a86-9fd3-40ca-bb9b-fe83c6981deb";

    public static final String NESTED_SCHEMA_ATTRIBUTE = "NestedSchemaAttribute";
    public static final String NESTED_SCHEMA_ATTRIBUTE_GUID = "0ffb9d87-7074-45da-a9b0-ae0859611133";

    public static final String NAME = "name";
    public static final String DESCRIPTION = "description";
    public static final String TYPE = "type";
    public static final String VERSION = "version";
    public static final String PATCH_LEVEL = "patchLevel";
    public static final String DEFAULT_SCHEMA_NAME = "gaian";
    public static final String QUALIFIED_NAME = "qualifiedName";
    public static final String DISPLAY_NAME = "displayName";
    public static final String SOFTWARE_SERVER_CAPABILITY_GUID = "fe30a033-8f86-4d17-8986-e6166fa24177";
    public static final String SOFTWARE_SERVER_CAPABILITY = "SoftwareCapability";

    private Constants() {
    }
}
